@@ -67,8 +67,8 @@ def distribution(returns, compounded=True, prepare_returns=True):
     return {
         "Daily": get_outliers(daily),
         "Weekly": get_outliers(daily.resample('W-MON').apply(apply_fnc)),
-        "mMonthly": get_outliers(daily.resample('M').apply(apply_fnc)),
-        "Auarterly": get_outliers(daily.resample('Q').apply(apply_fnc)),
+        "Monthly": get_outliers(daily.resample('M').apply(apply_fnc)),
+        "Quarterly": get_outliers(daily.resample('Q').apply(apply_fnc)),
         "Yearly": get_outliers(daily.resample('A').apply(apply_fnc))
     }
 
